@@ -2,24 +2,22 @@
 
 # Container-based collectors (backward compatibility)
 from .factory import TestResultCollectorFactory
-from .base import TestResultCollector
 
 # Core collectors (container-agnostic)
 from .core_factory import CoreTestResultCollectorFactory
-from .core import CoreTestResultCollector
+from .core_collector import CoreTestResultCollector
 
 # Container adapter
-from .container_adapter import ContainerTestResultCollector
+from .collector import TestResultCollector
 
 __all__ = [
     # Backward compatibility - container-based
     "TestResultCollectorFactory",
-    "TestResultCollector",
 
     # Core - container-agnostic
     "CoreTestResultCollectorFactory",
     "CoreTestResultCollector",
 
     # Container adapter
-    "ContainerTestResultCollector",
+    "TestResultCollector",
 ]
\ No newline at end of file
